@@ -17,7 +17,7 @@ import logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
-def crawl(splash_url: str, url: str, cookies: List[Dict[Any, Any]]=[], referer: Optional[str]=None, depth: int=1,
+def crawl(splash_url: str, url: str, *, cookies: List[Dict[Any, Any]]=[], referer: Optional[str]=None, depth: int=1,
           user_agent: str='Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36',
           log_enabled: bool=False, log_level: str='WARNING') -> List[Dict[Any, Any]]:
     '''Send the URL to crawl to splash, returns a list of responses from splash. Each entry from the list corresponds to a single URL loaded by Splash.'''
@@ -28,7 +28,8 @@ def crawl(splash_url: str, url: str, cookies: List[Dict[Any, Any]]=[], referer:
     def _crawl(queue, splash_url: str, ua: str, url: str,
                cookies: List[Dict[Any, Any]], referer: str,
                depth: int, log_enabled: bool, log_level: str) -> None:
-        crawler = ScrapySplashWrapperCrawler(splash_url, ua, cookies, referer, depth, log_enabled, log_level)
+        crawler = ScrapySplashWrapperCrawler(splash_url=splash_url, useragent=ua, cookies=cookies,
+                                             referer=referer, depth=depth, log_enabled=log_enabled, log_level=log_level)
         res = crawler.crawl(url)
         queue.put(res)
 
